ChessBoard class

Inheritance

Constructors

ChessBoard({Key? key, required ChessBoardController controller, double? size, bool enableUserMoves = true, BoardColor boardColor = BoardColor.brown, PlayerColor boardOrientation = PlayerColor.white, VoidCallback? onMove, List<BoardArrow> arrows = const []})
const

Properties

arrows → List<BoardArrow>
final
boardColor → BoardColor
The color type of the board
final
boardOrientation → PlayerColor
final
controller → ChessBoardController
An instance of ChessBoardController which holds the game and allows manipulating the board programmatically.
final
enableUserMoves → bool
A boolean which checks if the user should be allowed to make moves
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onMove → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
Size of chessboard
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ChessBoard>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited