ChessBoardController class

Inheritance

Properties

game ↔ Chess
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Chess
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearBoard() → void
Clears board
dispose() → void
Discards any resources used by the object.
inherited
getAscii() → String
getBoard() → List<Piece?>
getFen() → String
getHalfMoveCount() → int
getMoveCount() → int
getPossibleMoves() → List<Move>
getSan() → List<String?>
isCheckMate() → bool
isDraw() → bool
isGameOver() → bool
isInCheck() → bool
isInsufficientMaterial() → bool
isStaleMate() → bool
isThreefoldRepetition() → bool
loadFen(String fen) → void
Loads a PGN
loadPGN(String pgn) → void
Loads a PGN
makeMove({required String from, required String to}) → void
Makes move on the board
makeMoveWithNormalNotation(String move) → void
Makes move on the board
makeMoveWithPromotion({required String from, required String to, required String pieceToPromoteTo}) → void
Makes move and promotes pawn to piece (from is a square like d4, to is also a square like e3, pieceToPromoteTo is a String like "Q". pieceToPromoteTo String will be changed to enum in a future update and this method will be deprecated in the future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
putPiece(BoardPieceType piece, String square, PlayerColor color) → void
Puts piece on a square
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetBoard() → void
toString() → String
A string representation of this object.
inherited
undoMove() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited