Move class

Constructors

Move(Color color, int from, int to, int flags, PieceType piece, PieceType? captured, PieceType? promotion)
const

Properties

captured → PieceType?
final
color → Color
final
flags → int
final
from → int
final
fromAlgebraic → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
piece → PieceType
final
promotion → PieceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → int
final
toAlgebraic → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited