PieceMoveData class

Constructors

PieceMoveData({required String squareName, required String pieceType, required Color pieceColor})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pieceColor → Color
final
pieceType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
squareName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited