PieceType class

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shift → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLowerCase() → String
toString() → String
A string representation of this object.
override
toUpperCase() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

BISHOP → const PieceType
KING → const PieceType
KNIGHT → const PieceType
PAWN → const PieceType
QUEEN → const PieceType
ROOK → const PieceType